@@ -87,7 +87,8 @@ try {
             if (!check_permission('wordpress_update')) {
                 throw new Exception('Permission denied');
             }
-            $result = $wpManager->updateCore($_POST['site_id']);
+            $createBackup = isset($_POST['create_backup']) ? (bool)$_POST['create_backup'] : null;
+            $result = $wpManager->updateCore($_POST['site_id'], $createBackup);
             ob_clean(); // Clear buffer before output
             echo json_encode($result);
             exit;
@@ -96,7 +97,8 @@ try {
             if (!check_permission('wordpress_update')) {
                 throw new Exception('Permission denied');
             }
-            $result = $wpManager->updateAll($_POST['site_id']);
+            $createBackup = isset($_POST['create_backup']) ? (bool)$_POST['create_backup'] : null;
+            $result = $wpManager->updateAll($_POST['site_id'], $createBackup);
             ob_clean(); // Clear buffer before output
             echo json_encode($result);
             exit;
