@@ -2115,8 +2115,8 @@ Options -Indexes
 
         // Create the combined WordPress backup using BackupEngine (queued for background processing)
         $backupData = $this->backupEngine->createWordPressBackup(
-            $site['user'],
-            $site['domain'],
+            $siteId,
+            null, // Let BackupEngine generate backup name
             $site['preferred_backup_target_id'] ?? null
         );
 
@@ -2167,8 +2167,8 @@ Options -Indexes
 
         // Create the combined WordPress backup using BackupEngine (returns immediately)
         $backupData = $this->backupEngine->createWordPressBackup(
-            $site['user'],
-            $site['domain'],
+            $site['id'],
+            null, // Let BackupEngine generate backup name
             $site['preferred_backup_target_id'] ?? null
         );
 
